#!/bin/bash
# Service that renews Machine and Machine function certs on the machine
set -exou pipefail

if [ -z "${AP_MACHINE_NAME+x}" ] ; then
    AP_MACHINE_NAME=$(hostname)
fi

AP_ROOT=/ap
BOOTSTRAP_INI=${AP_ROOT}/data/LinuxBootstrapData.ini
MACHINE_CERT=/etc/ssl/certs/${AP_MACHINE_NAME}.crt
MAFUNCT_CERT=/etc/ssl/certs/${AP_MACHINE_NAME}.mf.crt

# We're using the /ap/data/LinuxBootstrapData.ini file until service discovery
# is implemented so we can grab the physical IP of the machine
if [ ! -f "${BOOTSTRAP_INI}" ] || [ ! -r "${BOOTSTRAP_INI}" ]; then
    print "ERROR: Could not find ${BOOTSTRAP_INI}. Or isn't readable"
    exit 1
fi

# Get IP
AP_IP=$(awk -F"=" '/AutopilotIPAddress/ {print $2}' ${BOOTSTRAP_INI})
if [ "${AP_IP}" == "" ] ; then
    print "ERROR: Could not find AutopilotIPAddress in ${BOOTSTRAP_INI}. Cannot proceed."
    exit 1
fi

# Get Cluster
AP_CLUSTER=$(awk -F"=" '/AutopilotCluster/ {print $2}' ${BOOTSTRAP_INI})
if [ "${AP_CLUSTER}" == "" ] ; then
    print "ERROR: Could not find AutopilotCluster in ${BOOTSTRAP_INI}. Cannot proceed."
    exit 1
fi

# Run localcertagent to download certificates if necessary
${AP_ROOT}/app/localcertagent/localcertagent.py -i ${AP_IP} -c ${AP_CLUSTER}

# Get cert info 
openssl x509 -in ${MACHINE_CERT} -text -noout -certopt no_header,no_version,no_signame,no_pubkey,no_sigdump,no_aux,no_serial
openssl x509 -in ${MAFUNCT_CERT} -text -noout -certopt no_header,no_version,no_signame,no_pubkey,no_sigdump,no_aux,no_serial
